.. ref-sdbdb

================
SDB DB Reference
================

This module offers an ORM-like layer on top of SimpleDB.

boto.sdb.db
-----------

.. automodule:: boto.sdb.db
   :members:
   :undoc-members:

boto.sdb.db.blob
----------------

.. automodule:: boto.sdb.db.blob
   :members:
   :undoc-members:

boto.sdb.db.key
---------------

.. automodule:: boto.sdb.db.key
   :members:
   :undoc-members:

boto.sdb.db.manager
-------------------

.. automodule:: boto.sdb.db.manager
   :members:
   :undoc-members:

boto.sdb.db.manager.sdbmanager
------------------------------

.. automodule:: boto.sdb.db.manager.sdbmanager
   :members:
   :undoc-members:

boto.sdb.db.manager.xmlmanager
------------------------------

.. automodule:: boto.sdb.db.manager.xmlmanager
   :members:
   :undoc-members:

boto.sdb.db.model
-----------------

.. automodule:: boto.sdb.db.model
   :members:
   :undoc-members:

boto.sdb.db.property
--------------------

.. automodule:: boto.sdb.db.property
   :members:
   :undoc-members:

boto.sdb.db.query
-----------------

.. automodule:: boto.sdb.db.query
   :members:
   :undoc-members:
